==> deb-installer_23.2.tar.xz: deb-installer-23.2/translations/deb-installer_tr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="tr">
<context>
    <name>Installer</name>
    <message>
        <location filename="../installer.cpp" line="84"/>
        <source>Remove</source>
        <translation>Kaldır</translation>
    </message>
    <message>
        <location filename="../installer.cpp" line="86"/>
        <location filename="../installer.cpp" line="116"/>
        <source>Install</source>
        <translation>Kur</translation>
    </message>
    <message>
        <location filename="../installer.cpp" line="89"/>
        <source>The following packages will be installed. Click &apos;Show Details...&apos; for information about the packages.</source>
        <translation>Aşağıdaki paketler kurulacaktır. Paketler hakkında bilgi edinmek için &apos;Ayrıntıları Göster...&apos;i tıklayın.</translation>
    </message>
    <message>
        <location filename="../installer.cpp" line="97"/>
        <source>File: %1</source>
        <translation>Dosya: %1</translation>
    </message>
    <message>
        <location filename="../installer.cpp" line="114"/>
        <source>Will install the following:</source>
        <translation>Aşağıdakiler kurulacak:</translation>
    </message>
    <message>
        <location filename="../installer.cpp" line="133"/>
        <source>Press any key to close</source>
        <translation>Kapatmak için herhangi bir tuşa basın</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="47"/>
        <source>Program for installing Debian binary packages (deb files)</source>
        <translation>Debian binary paketlerini kurma programı (deb dosyaları)</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="50"/>
        <source>files...</source>
        <translation>dosyalar...</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="50"/>
        <source>Name of .deb files to install</source>
        <translation>Kurulacak .deb dosyasının adı</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="51"/>
        <source>[file...]</source>
        <translation>[dosya...]</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="70"/>
        <source>Select .deb files to install</source>
        <translation>Kurulacak .deb dosyolarını seçin</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="71"/>
        <source>Deb Files (*.deb)</source>
        <translation>Deb Dosyaları (*.deb)</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="75"/>
        <source>No .deb files were provided.</source>
        <translation>Hiç .deb dosyası sağlanmadı.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="82"/>
        <location filename="../main.cpp" line="86"/>
        <location filename="../main.cpp" line="93"/>
        <source>Error</source>
        <translation>Hata</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="82"/>
        <source>File %1 not found</source>
        <translation>%1 dosyası bulunamadı.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="87"/>
        <source>File %1 is not a .deb file.</source>
        <translation>%1 dosyası .deb dosyası değil.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="93"/>
        <source>You must run this program as normal user.</source>
        <translation>Bu programı normal kullanıcı olarak çalıştırmalısınız.</translation>
    </message>
</context>
</TS>

==> deb-installer_23.8.02.tar.xz: deb-installer-23.8.02/translations/deb-installer_tr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="tr">
<context>
    <name>Installer</name>
    <message>
        <location filename="../installer.cpp" line="82"/>
        <source>Remove</source>
        <translation>Kaldır</translation>
    </message>
    <message>
        <location filename="../installer.cpp" line="85"/>
        <location filename="../installer.cpp" line="118"/>
        <source>Install</source>
        <translation>Kur</translation>
    </message>
    <message>
        <location filename="../installer.cpp" line="90"/>
        <source>The following packages will be installed. Click &apos;Show Details...&apos; for information about the packages.</source>
        <translation>Aşağıdaki paketler kurulacaktır. Paketler hakkında bilgi edinmek için ‘Ayrıntıları Göster...’i tıklayın.</translation>
    </message>
    <message>
        <location filename="../installer.cpp" line="98"/>
        <source>File: %1</source>
        <translation>Dosya: %1</translation>
    </message>
    <message>
        <location filename="../installer.cpp" line="115"/>
        <source>Will install the following:</source>
        <translation>Aşağıdakiler kurulacak:</translation>
    </message>
    <message>
        <location filename="../installer.cpp" line="130"/>
        <source>Installing selected package please authenticate</source>
        <translation>Seçili paket yükleniyor, lütfen onaylayın</translation>
    </message>
    <message>
        <location filename="../installer.cpp" line="136"/>
        <source>Press any key to close</source>
        <translation>Kapatmak için herhangi bir tuşa basın</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="46"/>
        <source>Program for installing Debian binary packages (deb files)</source>
        <translation>Debian binary paketlerini kurma programı (deb dosyaları)</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="49"/>
        <source>files...</source>
        <translation>dosyalar...</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="49"/>
        <source>Name of .deb files to install</source>
        <translation>Kurulacak .deb dosyasının adı</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="50"/>
        <source>[file...]</source>
        <translation>[dosya...]</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="72"/>
        <source>Select .deb files to install</source>
        <translation>Kurulacak .deb dosyolarını seçin</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="73"/>
        <source>Deb Files (*.deb)</source>
        <translation>Deb Dosyaları (*.deb)</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="77"/>
        <source>No .deb files were provided.</source>
        <translation>Hiç .deb dosyası sağlanmadı.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="84"/>
        <location filename="../main.cpp" line="88"/>
        <location filename="../main.cpp" line="96"/>
        <source>Error</source>
        <translation>Hata</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="84"/>
        <source>File %1 not found</source>
        <translation>%1 dosyası bulunamadı.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="89"/>
        <source>File %1 is not a .deb file.</source>
        <translation>%1 dosyası .deb dosyası değil.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="96"/>
        <source>You must run this program as normal user.</source>
        <translation>Bu programı normal kullanıcı olarak çalıştırmalısınız.</translation>
    </message>
</context>
</TS>
